# libtcrlm

This is the TCR language modelling library that powers SCEPTR.
It is a thin layer around PyTorch with some extra infrastructure.
Note that this repository only contains library code- for a readily-usable deployment of SCEPTR, or code used to train the models, please see the links below.

## Related links

|Link|Description|
|----|-----------|
|https://github.com/yutanagano/sceptr|Readily usable deployment of SCEPTR|
|https://github.com/yutanagano/tcrlm|Code used for training models|
